
configurator
============

|CircleCI|_  |Docs|_

.. |CircleCI| image:: https://circleci.com/gh/Simplistix/configurator/tree/master.svg?style=shield
.. _CircleCI: https://circleci.com/gh/Simplistix/configurator/tree/master

.. |Docs| image:: https://readthedocs.org/projects/configurator/badge/?version=latest
.. _Docs: http://configurator.readthedocs.org/en/latest/

This is a Python library for building a configuration store
from one or more layered configuration sources.

It provides an easy interface for accessing configuration information
sourced from overlaid config files or mapped in from environment variables
or command line options.

Configuration information is also available as nested, simple python data types so that
you can validate the schema of your configuration using the tool of your choice.

